version 10.0
#delimit ;
set more off;
log using "C:\matt\publications\jop2\jop\final_submission\replication\kastner.log", replace;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      kastner.do                                      *;
*       Date:           3/21/2012                                       *;
*       Author:         DJM/MG                                          *;
*       Purpose:        Kastner replication for JOP paper               *;
*       Input File:     TradeConflict.dta                               *;
*       Output File:    kastner.log                                     *;
*       Data Output:    None                                            *;
*       Previous file:  None                                            *;
*       Machine:        Matt's computer                                 *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 300m;

use "C:\matt\publications\jop2\jop\final_submission\replication\TradeConflict.dta", clear;

*     ****************************************************************  *;
*	  Replicate Kastner models as shown in Table 1, p. 676.             *;
*     ****************************************************************  *;

reg lnrtrade laglnrtrade lnrgdpab lndist lnrpciab avremote landlocked island 
    landratio pciratio jointdem logAvBCFE logUNsun lnBlnUN, cluster(undirectedcode);
    
reg lnrtrade laglnrtrade lnrgdpab lndist lnrpciab avremote landlocked island 
    landratio pciratio jointdem swprot logUNsun swprotsun, cluster(undirectedcode);

*     ****************************************************************  *;
*	  Rename variables                                                  *;
*     ****************************************************************  *;

rename lnrtrade trade;
rename logUNsun conflict;
rename logAvBCFE tradebarriers;
rename lnBlnUN conflict_tradebarriers;
sum;

*     ****************************************************************  *;
*       Main model                                                      *;
*     ****************************************************************  *;

reg trade conflict tradebarriers conflict_tradebarriers laglnrtrade lnrgdpab lndist lnrpciab 
    avremote landlocked island landratio pciratio jointdem, cluster(undirectedcode);

*     ****************************************************************  *;
*     ****************************************************************  *;
*	  Get stuff ready to produce marginal effect plots in Figure 4.     *;
*     ****************************************************************  *;
*     ****************************************************************  *;

reg trade conflict tradebarriers conflict_tradebarriers laglnrtrade lnrgdpab lndist lnrpciab 
    avremote landlocked island landratio pciratio jointdem, cluster(undirectedcode);

matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];


scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;

*     ****************************************************************  *;
*       Calculate data necessary for producing Figure 4a.               *;
*     ****************************************************************  *;

centile tradebarriers if e(sample), centile(20 80);
scalar p20=r(c_1);
scalar p80=r(c_2);
gen p20=p20;
gen p80=p80;

centile tradebarriers, centile(20 80);

generate MVZ=((_n-1)/100);

replace  MVZ=. if _n>414 | _n<97;

gen conbx=b1+b3*MVZ if _n<414;

gen consx=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) if _n<414; 

gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

*     ****************************************************************  *;
*       Calculate data necessary for producing Figure 4b.               *;
*     ****************************************************************  *;

generate MVX=((_n-1)/100);

replace  MVX=. if _n>110;

gen conbz=b2+b3*MVX if _n<110;

gen consz=sqrt(varb2+varb3*(MVX^2)+2*covb2b3*MVX) if _n<110; 

gen az=1.96*consz;
 
gen upperz=conbz+az;
 
gen lowerz=conbz-az;

*     ****************************************************************  *;
*       Construct variable to produce y=0 line.                         *;
*     ****************************************************************  *;

gen yline=0;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 4a.                                              *;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph twoway hist tradebarriers, width(0.1) percent color(gs14) yaxis(2)
        ||   rarea p20 p80 lowerx if lowerx>-0.51 & lowerx<0.51, horizontal sort color(gs12)
        ||   line conbx   MVZ, clwidth(medium) clpattern(solid) clcolor(blue) clcolor(black) yaxis(1)
        ||   line upperx  MVZ, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lowerx  MVZ, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(solid)
        ||   ,   
             xlabel(1 1.5 2 2.5 3 3.5 4,  nogrid labsize(2)) 
             ylabel(-1 0 1 2 3, axis(1) nogrid labsize(2))
             ylabel(0 3 6 9 12 15 18, axis(2) nogrid labsize(2))
             xscale(noline)
             yscale(noline alt)
             yscale(noline alt axis(2))
             legend(off)
             yline(0, lcolor(black) lpattern(dash) lwidth(thin)) 
             xtitle("" , size(2.5)  )
             ytitle("" , axis(2) size(2.5))
             xsca(titlegap(2))
             ysca(titlegap(2))
             scheme(s2mono) graphregion(fcolor(white));
                       
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 4b.                                              *;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph  twoway hist conflict, width(0.025) percent color(gs14) yaxis(2)
        ||   line conbz   MVX, clwidth(medium) clpattern(solid) clcolor(blue) clcolor(black)
        ||   line upperz  MVX, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lowerz  MVX, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
		     xlabel(0 .25 .5 .75 1, nogrid labsize(2)) 
             ylabel(-1.5 -1.25 -1 -.75 -.5 -.25 0 , axis(1) nogrid labsize(2))
             ylabel(0 2 4 6, axis(2) nogrid labsize(2))
             yscale(noline alt)
             yscale(noline alt axis(2))
             xscale(noline)
             legend(off)          
             yline(0, lcolor(black) lwidth(thin))
		     xtitle("" , size(2.5)  )
             ytitle("" , axis(2) size(2.5)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             scheme(s2mono) graphregion(fcolor(white));
             
*     ****************************************************************  *;
*       Regions of significance                                         *;
*     ****************************************************************  *;
          
sum MVZ if lowerx<0;

sum MVZ if lowerx<0 & upperx<0;

sum year;

sum year if tradebarriers>3.41;

sum year if tradebarriers<3.16;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       In the online appendix, we check the role of the linearity      *;
*       assumption as it relates to the marginal effect of Conflict on  *;
*       Trade at low levels of Trade Barriers. Let's start by adding a  *;
*       quadrative term.                                                *;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop upperx lowerx conbx consx MVZ ax;

*     ****************************************************************  *;
*       Create indicator to keep estimation observations the same.      *;
*     ****************************************************************  *;

reg trade conflict tradebarriers conflict_tradebarriers laglnrtrade lnrgdpab lndist lnrpciab 
    avremote landlocked island landratio pciratio jointdem, cluster(undirectedcode);

gen sample=1 if e(sample);

*     ****************************************************************  *;
*       Create quadratic term and interactions.                         *;
*     ****************************************************************  *;

generate tradebarriers2=tradebarriers*tradebarriers;

generate conflict_tradebarriers2=tradebarriers2*conflict;

*     ****************************************************************  *;
*	      Get stuff ready to produce new quadratic Figure 4a. This is   *;
*         Figure 7 in the Online Appendix.                              *;
*     ****************************************************************  *;

reg trade tradebarriers tradebarriers2 conflict conflict_tradebarriers conflict_tradebarriers2 laglnrtrade lnrgdpab lndist lnrpciab 
    avremote landlocked island landratio pciratio jointdem if sample==1, cluster(undirectedcode);
    
matrix b=e(b); 
matrix V=e(V);
 
scalar b1=b[1,1]; 
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];


scalar varb1=V[1,1]; 
scalar varb2=V[2,2]; 
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];

scalar covb1b3=V[1,3]; 
scalar covb1b2=V[1,2];
scalar covb1b4=V[1,4];
scalar covb1b5=V[1,5];
scalar covb2b3=V[2,3];
scalar covb2b4=V[2,4];
scalar covb2b5=V[2,5];
scalar covb3b4=V[3,4];
scalar covb3b5=V[3,5];
scalar covb4b5=V[4,5];

scalar list b1 b2 b3 b4 b5 varb1 varb2 varb3 varb4 varb5 covb1b3 covb2b3 covb3b4 covb3b5 covb4b5;
    
*     ****************************************************************  *;
*       Calculate data necessary for producing Figure 7 in Online       *;
*       Appendix.                                                       *;
*     ****************************************************************  *;
    
generate MVZ=((_n-1)/100);
replace  MVZ=. if _n>414 | _n<97;

gen conbx=b3+(b4*MVZ)+(b5*MVZ^2) if _n<414;

gen consx=sqrt(varb3+(MVZ^2*varb4)+(MVZ^4*varb5)+(2*MVZ*covb3b4)+(2*MVZ^2*covb3b5)+
				(2*MVZ^3*covb4b5)) if _n<414; 
gen ax=1.96*consx;
 
gen upperx=conbx+ax;
 
gen lowerx=conbx-ax;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 7 in Online Appendix.                            *;
*     ****************************************************************  *;
*     ****************************************************************  *;

graph twoway hist tradebarriers, percent width(0.1) color(gs14) yaxis(2)
        ||   line conbx   MVZ, clwidth(medium) clpattern(solid) clcolor(blue) clcolor(black) yaxis(1)
        ||   line upperx  MVZ, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lowerx  MVZ, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(solid)
        ||   ,   
             xlabel(1 1.5 2 2.5 3 3.5 4,  nogrid labsize(2)) 
             ylabel(-1 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15, angle(horizontal) axis(1) nogrid labsize(2))
             ylabel(0 3 6 9 12 15 18, angle(horizontal) axis(2) nogrid labsize(2))
             xscale(noline)
             yscale(noline alt)
             yscale(noline alt axis(2))
             legend(off)
             yline(0, lcolor(black) lpattern(solid) lwidth(thin)) 
             xtitle("" , size(2.5)  )
             ytitle("" , axis(2) size(2.5))
             xsca(titlegap(2))
             ysca(titlegap(2))
             scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));
                                     
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Regions of significance                                         *;
*     ****************************************************************  *;
*     ****************************************************************  *;
          
sum MVZ if lowerx>0 & lowerx<.;

sum MVZ if lowerx<0 & upperx<0;

sum year if sample==1;

*     ****************************************************************  *;
*       Positive and statistically significant.                         *;
*     ****************************************************************  *;

sum year if tradebarriers<3.04;

*     ****************************************************************  *;
*       Negative and statistically significant.                         *;
*     ****************************************************************  *;

sum year if tradebarriers>3.27 & tradebarriers<3.82;

*     ****************************************************************  *;
*     ****************************************************************  *;
*     ****************************************************************  *;
*       Now let's look at a cubic function.                             *;
*     ****************************************************************  *;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop upperx lowerx conbx consx MVZ ax;

*     ****************************************************************  *;
*       Create cubic terms and interactions                             *;
*     ****************************************************************  *;

generate tradebarriers3=tradebarriers*tradebarriers*tradebarriers;

generate conflict_tradebarriers3=tradebarriers3*conflict;

*     ****************************************************************  *;
*	    Get stuff ready to produce new cubic Figure 4a. This is Figure  *;
*       8 in the Online Appendix.                                       *;
*     ****************************************************************  *;

reg trade tradebarriers tradebarriers2 tradebarriers3 conflict conflict_tradebarriers conflict_tradebarriers2 conflict_tradebarriers3
	laglnrtrade lnrgdpab lndist lnrpciab avremote landlocked island landratio pciratio jointdem if sample==1, cluster(undirectedcode);

preserve;

set seed 10101;

drawnorm DM_b1-DM_b18, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost marg_hat lo hi a using "C:\matt\publications\jop2\jop\final_submission\replication\sim.dta", replace;

noisily display "start";
            
local a=.96 ;

while `a' <= 4.12 { ;

    {;

    generate ME_conflict = DM_b4 +
							DM_b5*(`a') +
							DM_b6*((`a')^2) +
							DM_b7*((`a')^3);
      
    gen marg=ME_conflict;
        
    egen marghat=mean(marg);
        
    tempname marg_hat lo hi;  

    _pctile marg, p(2.5,97.5);
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);
    scalar `marg_hat' = marghat;
    
    post mypost (`marg_hat') (`lo') (`hi') (`a');
	
    };      
	
    drop ME_conflict marg marghat;
    local a=`a'+ .01 ;
    display "." _c;
	
    } ;

display "";

postclose mypost;

*     ****************************************************************  *;
*       Outside of this do-file, we appended sim.dta to the bottom of   *;
*       Kastner's TradeConflict.dta to create TradeConflict_sim.dta.    *;
*     ****************************************************************  *;

use "C:\matt\publications\jop2\jop\final_submission\replication\TradeConflict_sim.dta", clear;

sum;

*     ****************************************************************  *;
*     ****************************************************************  *;
*       Produce Figure 8 for Online Appendix.                           *;
*     ****************************************************************  *;
*     ****************************************************************  *;

rename lnrtrade trade;
rename logUNsun conflict;
rename logAvBCFE tradebarriers;
rename lnBlnUN conflict_tradebarriers;
sum;

graph twoway hist tradebarriers, width(0.1) percent color(gs14) yaxis(2)
        ||   line marg_hat a, clwidth(medium) clpattern(solid) clcolor(blue) clcolor(black) yaxis(1)
        ||   line lo a, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hi a, clpattern(dash) clwidth(thin) clcolor(black) 
        ||   ,   
             xlabel(1 1.5 2 2.5 3 3.5 4,  nogrid labsize(2)) 
             ylabel(-15 -10 -5 0 5, axis(1) nogrid labsize(2))
             ylabel(0 3 6 9 12 15 18, axis(2) nogrid labsize(2))
             xscale(noline)
             yscale(noline alt)
             yscale(noline alt axis(2))
             legend(off)
             yline(0, lcolor(black) lpattern(solid) lwidth(thin)) 
             xtitle("" , size(2.5)  )
             ytitle("" , axis(2) size(2.5))
             xsca(titlegap(2))
             ysca(titlegap(2))
             scheme(s2mono) graphregion(fcolor(white));
                         
*     ****************************************************************  *;
*       Positive and statistically significant.                         *;
*     ****************************************************************  *;

reg trade conflict tradebarriers conflict_tradebarriers laglnrtrade lnrgdpab lndist lnrpciab 
    avremote landlocked island landratio pciratio jointdem, cluster(undirectedcode);

sum year if e(sample)==1;

sum year if tradebarriers>1.95 & tradebarriers<3.1;
sum year if tradebarriers>4.07;
sum year if tradebarriers<1.96;
           
log close;
